# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.19.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import metal_python
from metal_python.api.sizeimageconstraint_api import SizeimageconstraintApi  # noqa: E501
from metal_python.rest import ApiException


class TestSizeimageconstraintApi(unittest.TestCase):
    """SizeimageconstraintApi unit test stubs"""

    def setUp(self):
        self.api = metal_python.api.sizeimageconstraint_api.SizeimageconstraintApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_size_image_constraint(self):
        """Test case for create_size_image_constraint

        create a sizeimageconstraint. if the given ID already exists a conflict is returned  # noqa: E501
        """
        pass

    def test_delete_size_image_constraint(self):
        """Test case for delete_size_image_constraint

        deletes an sizeimageconstraint and returns the deleted entity  # noqa: E501
        """
        pass

    def test_find_size_image_constraint(self):
        """Test case for find_size_image_constraint

        get sizeimageconstraint by id  # noqa: E501
        """
        pass

    def test_list_size_image_constraints(self):
        """Test case for list_size_image_constraints

        get all sizeimageconstraints  # noqa: E501
        """
        pass

    def test_try_size_image_constraint(self):
        """Test case for try_size_image_constraint

        try if the given combination of image and size is supported and possible to allocate  # noqa: E501
        """
        pass

    def test_update_size_image_constraint(self):
        """Test case for update_size_image_constraint

        updates a sizeimageconstraint. if the sizeimageconstraint was changed since this one was read, a conflict is returned  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.19.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from metal_python.api_client import ApiClient


class ProjectApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_project(self, body, **kwargs):  # noqa: E501
        """create a project. if the given ID already exists a conflict is returned  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_project(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1ProjectCreateRequest body: (required)
        :return: V1ProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_project_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_project_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_project_with_http_info(self, body, **kwargs):  # noqa: E501
        """create a project. if the given ID already exists a conflict is returned  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_project_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1ProjectCreateRequest body: (required)
        :return: V1ProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['HMAC', 'jwt']  # noqa: E501

        return self.api_client.call_api(
            '/v1/project', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_project(self, id, **kwargs):  # noqa: E501
        """deletes a project and returns the deleted entity  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_project(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: identifier of the project (required)
        :return: V1ProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_project_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_project_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_project_with_http_info(self, id, **kwargs):  # noqa: E501
        """deletes a project and returns the deleted entity  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_project_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: identifier of the project (required)
        :return: V1ProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['HMAC', 'jwt']  # noqa: E501

        return self.api_client.call_api(
            '/v1/project/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_project(self, id, **kwargs):  # noqa: E501
        """get project by id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_project(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: identifier of the project (required)
        :return: V1ProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_project_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.find_project_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def find_project_with_http_info(self, id, **kwargs):  # noqa: E501
        """get project by id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_project_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: identifier of the project (required)
        :return: V1ProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `find_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['HMAC', 'jwt']  # noqa: E501

        return self.api_client.call_api(
            '/v1/project/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_projects(self, body, **kwargs):  # noqa: E501
        """get all projects that match given properties  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_projects(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1ProjectFindRequest body: (required)
        :return: list[V1ProjectResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_projects_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.find_projects_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def find_projects_with_http_info(self, body, **kwargs):  # noqa: E501
        """get all projects that match given properties  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_projects_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1ProjectFindRequest body: (required)
        :return: list[V1ProjectResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_projects" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `find_projects`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['HMAC', 'jwt']  # noqa: E501

        return self.api_client.call_api(
            '/v1/project/find', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[V1ProjectResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_projects(self, **kwargs):  # noqa: E501
        """get all projects  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_projects(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[V1ProjectResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_projects_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_projects_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_projects_with_http_info(self, **kwargs):  # noqa: E501
        """get all projects  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_projects_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[V1ProjectResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_projects" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['HMAC', 'jwt']  # noqa: E501

        return self.api_client.call_api(
            '/v1/project', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[V1ProjectResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_project(self, body, **kwargs):  # noqa: E501
        """update a project. optimistic lock error can occur.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_project(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1ProjectUpdateRequest body: (required)
        :return: V1ProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_project_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_project_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def update_project_with_http_info(self, body, **kwargs):  # noqa: E501
        """update a project. optimistic lock error can occur.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_project_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1ProjectUpdateRequest body: (required)
        :return: V1ProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['HMAC', 'jwt']  # noqa: E501

        return self.api_client.call_api(
            '/v1/project', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ProjectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.19.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1LogicalVolume(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'lvmtype': 'str',
        'name': 'str',
        'size': 'int',
        'volumegroup': 'str'
    }

    attribute_map = {
        'lvmtype': 'lvmtype',
        'name': 'name',
        'size': 'size',
        'volumegroup': 'volumegroup'
    }

    def __init__(self, lvmtype=None, name=None, size=None, volumegroup=None):  # noqa: E501
        """V1LogicalVolume - a model defined in Swagger"""  # noqa: E501

        self._lvmtype = None
        self._name = None
        self._size = None
        self._volumegroup = None
        self.discriminator = None

        self.lvmtype = lvmtype
        self.name = name
        self.size = size
        self.volumegroup = volumegroup

    @property
    def lvmtype(self):
        """Gets the lvmtype of this V1LogicalVolume.  # noqa: E501

        the type of this logical volume can be either linear|striped|raid1  # noqa: E501

        :return: The lvmtype of this V1LogicalVolume.  # noqa: E501
        :rtype: str
        """
        return self._lvmtype

    @lvmtype.setter
    def lvmtype(self, lvmtype):
        """Sets the lvmtype of this V1LogicalVolume.

        the type of this logical volume can be either linear|striped|raid1  # noqa: E501

        :param lvmtype: The lvmtype of this V1LogicalVolume.  # noqa: E501
        :type: str
        """
        if lvmtype is None:
            raise ValueError("Invalid value for `lvmtype`, must not be `None`")  # noqa: E501

        self._lvmtype = lvmtype

    @property
    def name(self):
        """Gets the name of this V1LogicalVolume.  # noqa: E501

        the name of the logical volume  # noqa: E501

        :return: The name of this V1LogicalVolume.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1LogicalVolume.

        the name of the logical volume  # noqa: E501

        :param name: The name of this V1LogicalVolume.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def size(self):
        """Gets the size of this V1LogicalVolume.  # noqa: E501

        size in mebibytes (MiB) of this volume  # noqa: E501

        :return: The size of this V1LogicalVolume.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this V1LogicalVolume.

        size in mebibytes (MiB) of this volume  # noqa: E501

        :param size: The size of this V1LogicalVolume.  # noqa: E501
        :type: int
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    @property
    def volumegroup(self):
        """Gets the volumegroup of this V1LogicalVolume.  # noqa: E501

        the name of the volume group where to create the logical volume onto  # noqa: E501

        :return: The volumegroup of this V1LogicalVolume.  # noqa: E501
        :rtype: str
        """
        return self._volumegroup

    @volumegroup.setter
    def volumegroup(self, volumegroup):
        """Sets the volumegroup of this V1LogicalVolume.

        the name of the volume group where to create the logical volume onto  # noqa: E501

        :param volumegroup: The volumegroup of this V1LogicalVolume.  # noqa: E501
        :type: str
        """
        if volumegroup is None:
            raise ValueError("Invalid value for `volumegroup`, must not be `None`")  # noqa: E501

        self._volumegroup = volumegroup

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1LogicalVolume, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1LogicalVolume):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.19.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1MachineUpdateFirmwareRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'kind': 'str',
        'revision': 'str'
    }

    attribute_map = {
        'description': 'description',
        'kind': 'kind',
        'revision': 'revision'
    }

    def __init__(self, description=None, kind=None, revision=None):  # noqa: E501
        """V1MachineUpdateFirmwareRequest - a model defined in Swagger"""  # noqa: E501

        self._description = None
        self._kind = None
        self._revision = None
        self.discriminator = None

        self.description = description
        self.kind = kind
        self.revision = revision

    @property
    def description(self):
        """Gets the description of this V1MachineUpdateFirmwareRequest.  # noqa: E501

        a description why the machine has been updated  # noqa: E501

        :return: The description of this V1MachineUpdateFirmwareRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1MachineUpdateFirmwareRequest.

        a description why the machine has been updated  # noqa: E501

        :param description: The description of this V1MachineUpdateFirmwareRequest.  # noqa: E501
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def kind(self):
        """Gets the kind of this V1MachineUpdateFirmwareRequest.  # noqa: E501

        the firmware kind, i.e. [bios|bmc]  # noqa: E501

        :return: The kind of this V1MachineUpdateFirmwareRequest.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this V1MachineUpdateFirmwareRequest.

        the firmware kind, i.e. [bios|bmc]  # noqa: E501

        :param kind: The kind of this V1MachineUpdateFirmwareRequest.  # noqa: E501
        :type: str
        """
        if kind is None:
            raise ValueError("Invalid value for `kind`, must not be `None`")  # noqa: E501
        allowed_values = ["bios", "bmc"]  # noqa: E501
        if kind not in allowed_values:
            raise ValueError(
                "Invalid value for `kind` ({0}), must be one of {1}"  # noqa: E501
                .format(kind, allowed_values)
            )

        self._kind = kind

    @property
    def revision(self):
        """Gets the revision of this V1MachineUpdateFirmwareRequest.  # noqa: E501

        the update revision  # noqa: E501

        :return: The revision of this V1MachineUpdateFirmwareRequest.  # noqa: E501
        :rtype: str
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this V1MachineUpdateFirmwareRequest.

        the update revision  # noqa: E501

        :param revision: The revision of this V1MachineUpdateFirmwareRequest.  # noqa: E501
        :type: str
        """
        if revision is None:
            raise ValueError("Invalid value for `revision`, must not be `None`")  # noqa: E501

        self._revision = revision

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1MachineUpdateFirmwareRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MachineUpdateFirmwareRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.19.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1Filesystem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'createoptions': 'list[str]',
        'device': 'str',
        'format': 'str',
        'label': 'str',
        'mountoptions': 'list[str]',
        'path': 'str'
    }

    attribute_map = {
        'createoptions': 'createoptions',
        'device': 'device',
        'format': 'format',
        'label': 'label',
        'mountoptions': 'mountoptions',
        'path': 'path'
    }

    def __init__(self, createoptions=None, device=None, format=None, label=None, mountoptions=None, path=None):  # noqa: E501
        """V1Filesystem - a model defined in Swagger"""  # noqa: E501

        self._createoptions = None
        self._device = None
        self._format = None
        self._label = None
        self._mountoptions = None
        self._path = None
        self.discriminator = None

        if createoptions is not None:
            self.createoptions = createoptions
        self.device = device
        self.format = format
        if label is not None:
            self.label = label
        if mountoptions is not None:
            self.mountoptions = mountoptions
        if path is not None:
            self.path = path

    @property
    def createoptions(self):
        """Gets the createoptions of this V1Filesystem.  # noqa: E501

        the options to use to create (mkfs) this filesystem  # noqa: E501

        :return: The createoptions of this V1Filesystem.  # noqa: E501
        :rtype: list[str]
        """
        return self._createoptions

    @createoptions.setter
    def createoptions(self, createoptions):
        """Sets the createoptions of this V1Filesystem.

        the options to use to create (mkfs) this filesystem  # noqa: E501

        :param createoptions: The createoptions of this V1Filesystem.  # noqa: E501
        :type: list[str]
        """

        self._createoptions = createoptions

    @property
    def device(self):
        """Gets the device of this V1Filesystem.  # noqa: E501

        the underlaying device where this filesystem should be created  # noqa: E501

        :return: The device of this V1Filesystem.  # noqa: E501
        :rtype: str
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this V1Filesystem.

        the underlaying device where this filesystem should be created  # noqa: E501

        :param device: The device of this V1Filesystem.  # noqa: E501
        :type: str
        """
        if device is None:
            raise ValueError("Invalid value for `device`, must not be `None`")  # noqa: E501

        self._device = device

    @property
    def format(self):
        """Gets the format of this V1Filesystem.  # noqa: E501

        the filesystem format  # noqa: E501

        :return: The format of this V1Filesystem.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this V1Filesystem.

        the filesystem format  # noqa: E501

        :param format: The format of this V1Filesystem.  # noqa: E501
        :type: str
        """
        if format is None:
            raise ValueError("Invalid value for `format`, must not be `None`")  # noqa: E501

        self._format = format

    @property
    def label(self):
        """Gets the label of this V1Filesystem.  # noqa: E501

        optional label for this this filesystem  # noqa: E501

        :return: The label of this V1Filesystem.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this V1Filesystem.

        optional label for this this filesystem  # noqa: E501

        :param label: The label of this V1Filesystem.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def mountoptions(self):
        """Gets the mountoptions of this V1Filesystem.  # noqa: E501

        the options to use to mount this filesystem  # noqa: E501

        :return: The mountoptions of this V1Filesystem.  # noqa: E501
        :rtype: list[str]
        """
        return self._mountoptions

    @mountoptions.setter
    def mountoptions(self, mountoptions):
        """Sets the mountoptions of this V1Filesystem.

        the options to use to mount this filesystem  # noqa: E501

        :param mountoptions: The mountoptions of this V1Filesystem.  # noqa: E501
        :type: list[str]
        """

        self._mountoptions = mountoptions

    @property
    def path(self):
        """Gets the path of this V1Filesystem.  # noqa: E501

        the mountpoint where this filesystem should be mounted on  # noqa: E501

        :return: The path of this V1Filesystem.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this V1Filesystem.

        the mountpoint where this filesystem should be mounted on  # noqa: E501

        :param path: The path of this V1Filesystem.  # noqa: E501
        :type: str
        """

        self._path = path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1Filesystem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Filesystem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.19.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import metal_python
from metal_python.api.tenant_api import TenantApi  # noqa: E501
from metal_python.rest import ApiException


class TestTenantApi(unittest.TestCase):
    """TenantApi unit test stubs"""

    def setUp(self):
        self.api = metal_python.api.tenant_api.TenantApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_tenant(self):
        """Test case for get_tenant

        get tenant by id  # noqa: E501
        """
        pass

    def test_list_tenants(self):
        """Test case for list_tenants

        get all tenants  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.19.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1User(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'e_mail': 'str',
        'groups': 'list[str]',
        'issuer': 'str',
        'name': 'str',
        'subject': 'str',
        'tenant': 'str'
    }

    attribute_map = {
        'e_mail': 'EMail',
        'groups': 'Groups',
        'issuer': 'Issuer',
        'name': 'Name',
        'subject': 'Subject',
        'tenant': 'Tenant'
    }

    def __init__(self, e_mail=None, groups=None, issuer=None, name=None, subject=None, tenant=None):  # noqa: E501
        """V1User - a model defined in Swagger"""  # noqa: E501

        self._e_mail = None
        self._groups = None
        self._issuer = None
        self._name = None
        self._subject = None
        self._tenant = None
        self.discriminator = None

        self.e_mail = e_mail
        self.groups = groups
        self.issuer = issuer
        self.name = name
        self.subject = subject
        self.tenant = tenant

    @property
    def e_mail(self):
        """Gets the e_mail of this V1User.  # noqa: E501


        :return: The e_mail of this V1User.  # noqa: E501
        :rtype: str
        """
        return self._e_mail

    @e_mail.setter
    def e_mail(self, e_mail):
        """Sets the e_mail of this V1User.


        :param e_mail: The e_mail of this V1User.  # noqa: E501
        :type: str
        """
        if e_mail is None:
            raise ValueError("Invalid value for `e_mail`, must not be `None`")  # noqa: E501

        self._e_mail = e_mail

    @property
    def groups(self):
        """Gets the groups of this V1User.  # noqa: E501


        :return: The groups of this V1User.  # noqa: E501
        :rtype: list[str]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """Sets the groups of this V1User.


        :param groups: The groups of this V1User.  # noqa: E501
        :type: list[str]
        """
        if groups is None:
            raise ValueError("Invalid value for `groups`, must not be `None`")  # noqa: E501

        self._groups = groups

    @property
    def issuer(self):
        """Gets the issuer of this V1User.  # noqa: E501


        :return: The issuer of this V1User.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this V1User.


        :param issuer: The issuer of this V1User.  # noqa: E501
        :type: str
        """
        if issuer is None:
            raise ValueError("Invalid value for `issuer`, must not be `None`")  # noqa: E501

        self._issuer = issuer

    @property
    def name(self):
        """Gets the name of this V1User.  # noqa: E501


        :return: The name of this V1User.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1User.


        :param name: The name of this V1User.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def subject(self):
        """Gets the subject of this V1User.  # noqa: E501


        :return: The subject of this V1User.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this V1User.


        :param subject: The subject of this V1User.  # noqa: E501
        :type: str
        """
        if subject is None:
            raise ValueError("Invalid value for `subject`, must not be `None`")  # noqa: E501

        self._subject = subject

    @property
    def tenant(self):
        """Gets the tenant of this V1User.  # noqa: E501


        :return: The tenant of this V1User.  # noqa: E501
        :rtype: str
        """
        return self._tenant

    @tenant.setter
    def tenant(self, tenant):
        """Sets the tenant of this V1User.


        :param tenant: The tenant of this V1User.  # noqa: E501
        :type: str
        """
        if tenant is None:
            raise ValueError("Invalid value for `tenant`, must not be `None`")  # noqa: E501

        self._tenant = tenant

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1User, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1User):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.19.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from metal_python.models.datastore_ip_search_query import DatastoreIPSearchQuery
from metal_python.models.datastore_machine_search_query import DatastoreMachineSearchQuery
from metal_python.models.datastore_network_search_query import DatastoreNetworkSearchQuery
from metal_python.models.httperrors_http_error_response import HttperrorsHTTPErrorResponse
from metal_python.models.rest_health_response import RestHealthResponse
from metal_python.models.rest_health_result import RestHealthResult
from metal_python.models.rest_version import RestVersion
from metal_python.models.v1_bgp_filter import V1BGPFilter
from metal_python.models.v1_board_revisions import V1BoardRevisions
from metal_python.models.v1_boot_info import V1BootInfo
from metal_python.models.v1_chassis_identify_led_state import V1ChassisIdentifyLEDState
from metal_python.models.v1_common import V1Common
from metal_python.models.v1_describable import V1Describable
from metal_python.models.v1_disk import V1Disk
from metal_python.models.v1_disk_partition import V1DiskPartition
from metal_python.models.v1_empty_body import V1EmptyBody
from metal_python.models.v1_filesystem import V1Filesystem
from metal_python.models.v1_filesystem_layout_base import V1FilesystemLayoutBase
from metal_python.models.v1_filesystem_layout_constraints import V1FilesystemLayoutConstraints
from metal_python.models.v1_filesystem_layout_create_request import V1FilesystemLayoutCreateRequest
from metal_python.models.v1_filesystem_layout_match_request import V1FilesystemLayoutMatchRequest
from metal_python.models.v1_filesystem_layout_response import V1FilesystemLayoutResponse
from metal_python.models.v1_filesystem_layout_try_request import V1FilesystemLayoutTryRequest
from metal_python.models.v1_filesystem_layout_update_request import V1FilesystemLayoutUpdateRequest
from metal_python.models.v1_firewall_create_request import V1FirewallCreateRequest
from metal_python.models.v1_firewall_find_request import V1FirewallFindRequest
from metal_python.models.v1_firewall_response import V1FirewallResponse
from metal_python.models.v1_firmwares_response import V1FirmwaresResponse
from metal_python.models.v1_iam_config import V1IAMConfig
from metal_python.models.v1_idm_config import V1IDMConfig
from metal_python.models.v1_ip_allocate_request import V1IPAllocateRequest
from metal_python.models.v1_ip_base import V1IPBase
from metal_python.models.v1_ip_find_request import V1IPFindRequest
from metal_python.models.v1_ip_identifiable import V1IPIdentifiable
from metal_python.models.v1_ip_response import V1IPResponse
from metal_python.models.v1_ip_update_request import V1IPUpdateRequest
from metal_python.models.v1_identifiable import V1Identifiable
from metal_python.models.v1_image_base import V1ImageBase
from metal_python.models.v1_image_create_request import V1ImageCreateRequest
from metal_python.models.v1_image_response import V1ImageResponse
from metal_python.models.v1_image_update_request import V1ImageUpdateRequest
from metal_python.models.v1_issuer_config import V1IssuerConfig
from metal_python.models.v1_logical_volume import V1LogicalVolume
from metal_python.models.v1_machine_abort_reinstall_request import V1MachineAbortReinstallRequest
from metal_python.models.v1_machine_allocate_request import V1MachineAllocateRequest
from metal_python.models.v1_machine_allocation import V1MachineAllocation
from metal_python.models.v1_machine_allocation_network import V1MachineAllocationNetwork
from metal_python.models.v1_machine_bios import V1MachineBIOS
from metal_python.models.v1_machine_base import V1MachineBase
from metal_python.models.v1_machine_block_device import V1MachineBlockDevice
from metal_python.models.v1_machine_console_password_request import V1MachineConsolePasswordRequest
from metal_python.models.v1_machine_console_password_response import V1MachineConsolePasswordResponse
from metal_python.models.v1_machine_finalize_allocation_request import V1MachineFinalizeAllocationRequest
from metal_python.models.v1_machine_find_request import V1MachineFindRequest
from metal_python.models.v1_machine_fru import V1MachineFru
from metal_python.models.v1_machine_hardware import V1MachineHardware
from metal_python.models.v1_machine_hardware_base import V1MachineHardwareBase
from metal_python.models.v1_machine_ipmi import V1MachineIPMI
from metal_python.models.v1_machine_ipmi_response import V1MachineIPMIResponse
from metal_python.models.v1_machine_ipmi_report import V1MachineIpmiReport
from metal_python.models.v1_machine_ipmi_report_response import V1MachineIpmiReportResponse
from metal_python.models.v1_machine_ipmi_reports import V1MachineIpmiReports
from metal_python.models.v1_machine_network import V1MachineNetwork
from metal_python.models.v1_machine_nic import V1MachineNic
from metal_python.models.v1_machine_provisioning_event import V1MachineProvisioningEvent
from metal_python.models.v1_machine_provisioning_events import V1MachineProvisioningEvents
from metal_python.models.v1_machine_recent_provisioning_events import V1MachineRecentProvisioningEvents
from metal_python.models.v1_machine_recent_provisioning_events_response import V1MachineRecentProvisioningEventsResponse
from metal_python.models.v1_machine_register_request import V1MachineRegisterRequest
from metal_python.models.v1_machine_reinstall_request import V1MachineReinstallRequest
from metal_python.models.v1_machine_response import V1MachineResponse
from metal_python.models.v1_machine_state import V1MachineState
from metal_python.models.v1_machine_update_firmware_request import V1MachineUpdateFirmwareRequest
from metal_python.models.v1_machine_update_request import V1MachineUpdateRequest
from metal_python.models.v1_meta import V1Meta
from metal_python.models.v1_network_allocate_request import V1NetworkAllocateRequest
from metal_python.models.v1_network_base import V1NetworkBase
from metal_python.models.v1_network_create_request import V1NetworkCreateRequest
from metal_python.models.v1_network_find_request import V1NetworkFindRequest
from metal_python.models.v1_network_immutable import V1NetworkImmutable
from metal_python.models.v1_network_response import V1NetworkResponse
from metal_python.models.v1_network_update_request import V1NetworkUpdateRequest
from metal_python.models.v1_network_usage import V1NetworkUsage
from metal_python.models.v1_partition_base import V1PartitionBase
from metal_python.models.v1_partition_boot_configuration import V1PartitionBootConfiguration
from metal_python.models.v1_partition_capacity import V1PartitionCapacity
from metal_python.models.v1_partition_capacity_request import V1PartitionCapacityRequest
from metal_python.models.v1_partition_create_request import V1PartitionCreateRequest
from metal_python.models.v1_partition_response import V1PartitionResponse
from metal_python.models.v1_partition_update_request import V1PartitionUpdateRequest
from metal_python.models.v1_project import V1Project
from metal_python.models.v1_project_create_request import V1ProjectCreateRequest
from metal_python.models.v1_project_find_request import V1ProjectFindRequest
from metal_python.models.v1_project_response import V1ProjectResponse
from metal_python.models.v1_project_update_request import V1ProjectUpdateRequest
from metal_python.models.v1_quota import V1Quota
from metal_python.models.v1_quota_set import V1QuotaSet
from metal_python.models.v1_raid import V1Raid
from metal_python.models.v1_server_capacity import V1ServerCapacity
from metal_python.models.v1_size_constraint import V1SizeConstraint
from metal_python.models.v1_size_constraint_matching_log import V1SizeConstraintMatchingLog
from metal_python.models.v1_size_create_request import V1SizeCreateRequest
from metal_python.models.v1_size_image_constraint_base import V1SizeImageConstraintBase
from metal_python.models.v1_size_image_constraint_create_request import V1SizeImageConstraintCreateRequest
from metal_python.models.v1_size_image_constraint_response import V1SizeImageConstraintResponse
from metal_python.models.v1_size_image_constraint_try_request import V1SizeImageConstraintTryRequest
from metal_python.models.v1_size_image_constraint_update_request import V1SizeImageConstraintUpdateRequest
from metal_python.models.v1_size_matching_log import V1SizeMatchingLog
from metal_python.models.v1_size_response import V1SizeResponse
from metal_python.models.v1_size_update_request import V1SizeUpdateRequest
from metal_python.models.v1_switch_base import V1SwitchBase
from metal_python.models.v1_switch_connection import V1SwitchConnection
from metal_python.models.v1_switch_nic import V1SwitchNic
from metal_python.models.v1_switch_notify_request import V1SwitchNotifyRequest
from metal_python.models.v1_switch_register_request import V1SwitchRegisterRequest
from metal_python.models.v1_switch_response import V1SwitchResponse
from metal_python.models.v1_switch_sync import V1SwitchSync
from metal_python.models.v1_switch_update_request import V1SwitchUpdateRequest
from metal_python.models.v1_tenant import V1Tenant
from metal_python.models.v1_tenant_response import V1TenantResponse
from metal_python.models.v1_timestamps import V1Timestamps
from metal_python.models.v1_user import V1User
from metal_python.models.v1_vendor_revisions import V1VendorRevisions
from metal_python.models.v1_volume_group import V1VolumeGroup



# coding: utf-8

"""
    metal-api

    API to manage and control plane resources like machines, switches, operating system images, machine sizes, networks, IP addresses and more  # noqa: E501

    OpenAPI spec version: v0.19.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1MachineRecentProvisioningEvents(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'crash_loop': 'bool',
        'failed_machine_reclaim': 'bool',
        'incomplete_provisioning_cycles': 'str',
        'last_error_event': 'V1MachineProvisioningEvent',
        'last_event_time': 'datetime',
        'log': 'list[V1MachineProvisioningEvent]'
    }

    attribute_map = {
        'crash_loop': 'crash_loop',
        'failed_machine_reclaim': 'failed_machine_reclaim',
        'incomplete_provisioning_cycles': 'incomplete_provisioning_cycles',
        'last_error_event': 'last_error_event',
        'last_event_time': 'last_event_time',
        'log': 'log'
    }

    def __init__(self, crash_loop=None, failed_machine_reclaim=None, incomplete_provisioning_cycles=None, last_error_event=None, last_event_time=None, log=None):  # noqa: E501
        """V1MachineRecentProvisioningEvents - a model defined in Swagger"""  # noqa: E501

        self._crash_loop = None
        self._failed_machine_reclaim = None
        self._incomplete_provisioning_cycles = None
        self._last_error_event = None
        self._last_event_time = None
        self._log = None
        self.discriminator = None

        self.crash_loop = crash_loop
        self.failed_machine_reclaim = failed_machine_reclaim
        self.incomplete_provisioning_cycles = incomplete_provisioning_cycles
        if last_error_event is not None:
            self.last_error_event = last_error_event
        if last_event_time is not None:
            self.last_event_time = last_event_time
        self.log = log

    @property
    def crash_loop(self):
        """Gets the crash_loop of this V1MachineRecentProvisioningEvents.  # noqa: E501

        indicates that machine is provisioning crash loop  # noqa: E501

        :return: The crash_loop of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :rtype: bool
        """
        return self._crash_loop

    @crash_loop.setter
    def crash_loop(self, crash_loop):
        """Sets the crash_loop of this V1MachineRecentProvisioningEvents.

        indicates that machine is provisioning crash loop  # noqa: E501

        :param crash_loop: The crash_loop of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :type: bool
        """
        if crash_loop is None:
            raise ValueError("Invalid value for `crash_loop`, must not be `None`")  # noqa: E501

        self._crash_loop = crash_loop

    @property
    def failed_machine_reclaim(self):
        """Gets the failed_machine_reclaim of this V1MachineRecentProvisioningEvents.  # noqa: E501

        indicates that machine reclaim has failed  # noqa: E501

        :return: The failed_machine_reclaim of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :rtype: bool
        """
        return self._failed_machine_reclaim

    @failed_machine_reclaim.setter
    def failed_machine_reclaim(self, failed_machine_reclaim):
        """Sets the failed_machine_reclaim of this V1MachineRecentProvisioningEvents.

        indicates that machine reclaim has failed  # noqa: E501

        :param failed_machine_reclaim: The failed_machine_reclaim of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :type: bool
        """
        if failed_machine_reclaim is None:
            raise ValueError("Invalid value for `failed_machine_reclaim`, must not be `None`")  # noqa: E501

        self._failed_machine_reclaim = failed_machine_reclaim

    @property
    def incomplete_provisioning_cycles(self):
        """Gets the incomplete_provisioning_cycles of this V1MachineRecentProvisioningEvents.  # noqa: E501

        The field 'IncompleteProvisioningCycles' in the provisioning events container is now deprecated and replaced by two new bool flags 'CrashLoop' and 'MachineReclaimFailed'.  # noqa: E501

        :return: The incomplete_provisioning_cycles of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :rtype: str
        """
        return self._incomplete_provisioning_cycles

    @incomplete_provisioning_cycles.setter
    def incomplete_provisioning_cycles(self, incomplete_provisioning_cycles):
        """Sets the incomplete_provisioning_cycles of this V1MachineRecentProvisioningEvents.

        The field 'IncompleteProvisioningCycles' in the provisioning events container is now deprecated and replaced by two new bool flags 'CrashLoop' and 'MachineReclaimFailed'.  # noqa: E501

        :param incomplete_provisioning_cycles: The incomplete_provisioning_cycles of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :type: str
        """
        if incomplete_provisioning_cycles is None:
            raise ValueError("Invalid value for `incomplete_provisioning_cycles`, must not be `None`")  # noqa: E501

        self._incomplete_provisioning_cycles = incomplete_provisioning_cycles

    @property
    def last_error_event(self):
        """Gets the last_error_event of this V1MachineRecentProvisioningEvents.  # noqa: E501

        the last erroneous event received  # noqa: E501

        :return: The last_error_event of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :rtype: V1MachineProvisioningEvent
        """
        return self._last_error_event

    @last_error_event.setter
    def last_error_event(self, last_error_event):
        """Sets the last_error_event of this V1MachineRecentProvisioningEvents.

        the last erroneous event received  # noqa: E501

        :param last_error_event: The last_error_event of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :type: V1MachineProvisioningEvent
        """

        self._last_error_event = last_error_event

    @property
    def last_event_time(self):
        """Gets the last_event_time of this V1MachineRecentProvisioningEvents.  # noqa: E501

        the time where the last event was received  # noqa: E501

        :return: The last_event_time of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :rtype: datetime
        """
        return self._last_event_time

    @last_event_time.setter
    def last_event_time(self, last_event_time):
        """Sets the last_event_time of this V1MachineRecentProvisioningEvents.

        the time where the last event was received  # noqa: E501

        :param last_event_time: The last_event_time of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :type: datetime
        """

        self._last_event_time = last_event_time

    @property
    def log(self):
        """Gets the log of this V1MachineRecentProvisioningEvents.  # noqa: E501

        the log of recent machine provisioning events  # noqa: E501

        :return: The log of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :rtype: list[V1MachineProvisioningEvent]
        """
        return self._log

    @log.setter
    def log(self, log):
        """Sets the log of this V1MachineRecentProvisioningEvents.

        the log of recent machine provisioning events  # noqa: E501

        :param log: The log of this V1MachineRecentProvisioningEvents.  # noqa: E501
        :type: list[V1MachineProvisioningEvent]
        """
        if log is None:
            raise ValueError("Invalid value for `log`, must not be `None`")  # noqa: E501

        self._log = log

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1MachineRecentProvisioningEvents, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1MachineRecentProvisioningEvents):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
